# Tchotchke

Trinkets and baubles to adorn your pythonic pursuits. A collection of unrelated useful utilities.

## Many Thanks To

- **[loguru](https://pypi.org/project/loguru/)**
- **[ujson](https://pypi.org/project/ujson/)**
- **[PyYAML](https://pypi.org/project/PyYAML/)** 